@@ -10,7 +10,7 @@ use Lemonldap::NG::Handler::CGI qw(:globalStorage :locationRules);    #inherits
 use Lemonldap::NG::Common::Conf;              #link protected conf Configuration
 use Lemonldap::NG::Common::Conf::Constants;   #inherits
 
-our $VERSION = '1.4.5';
+our $VERSION = '1.4.7';
 our @ISA     = qw(
   Lemonldap::NG::Handler::CGI
   Lemonldap::NG::Manager::Downloader
@@ -20,6 +20,9 @@ our @ISA     = qw(
   Lemonldap::NG::Manager::_i18n
 );
 
+*li = *Lemonldap::NG::Manager::Downloader::li;
+*span = *Lemonldap::NG::Manager::Downloader::span;
+
 ## @cmethod Lemonldap::NG::Manager new(hashRef args)
 # Class constructor.
 #@param args hash reference
